@@ -41,6 +41,7 @@ class SimpleClassificationModel(AbstractClassificationModel):
         x = tf.keras.layers.Conv2D(filters=128,kernel_size=(3,3),padding="same")(x) 
         x = tf.keras.layers.Activation('relu')(x)
         x = tf.keras.layers.MaxPool2D((2,2))(x)
+        x = tf.keras.layers.GlobalAveragePooling2D()(x)
         model = tf.keras.Model(inputs=inputs,outputs=x)
         return model
 
@@ -50,8 +51,8 @@ class KerasResNet50(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str,**kwargs) -> tf.keras.Model:
-        model = tf.keras.applications.ResNet50(include_top=False, weights=None, input_shape=input_shape,pooling="avg")
+    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+        model = tf.keras.applications.ResNet50(include_top=False, weights=weights, input_shape=input_shape,pooling="avg")
         return model
 
 class KerasResNet50V2(AbstractClassificationModel):
@@ -60,8 +61,8 @@ class KerasResNet50V2(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str,**kwargs) -> tf.keras.Model:
-        model = tf.keras.applications.ResNet50V2(include_top=False, weights=None, input_shape=input_shape,pooling="avg")
+    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+        model = tf.keras.applications.ResNet50V2(include_top=False, weights=weights, input_shape=input_shape,pooling="avg")
         return model
 
 class KerasMobileNetV2(AbstractClassificationModel):
@@ -70,8 +71,8 @@ class KerasMobileNetV2(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str,**kwargs) -> tf.keras.Model:
-        model = tf.keras.applications.MobileNetV2(include_top=False, weights=None, input_shape=input_shape,pooling="avg")
+    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+        model = tf.keras.applications.MobileNetV2(include_top=False, weights=weights, input_shape=input_shape,pooling="avg")
         return model
 
 class KerasEfficentNetB0(AbstractClassificationModel):
@@ -80,8 +81,8 @@ class KerasEfficentNetB0(AbstractClassificationModel):
         pass
     
     @classmethod
-    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str,**kwargs) -> tf.keras.Model:
-        model = tf.keras.applications.EfficientNetB0(include_top=False, weights=None, input_shape=input_shape, pooling="avg")
+    def get_base_model(cls,input_shape:(int,int,int),include_top:bool,weights:str=None,**kwargs) -> tf.keras.Model:
+        model = tf.keras.applications.EfficientNetB0(include_top=False, weights=weights, input_shape=input_shape, pooling="avg")
         return model
 
 
@@ -97,18 +98,11 @@ class ClassificationModel():
         input = base_model.input
         last = base_model.output
 
-
-        x = tf.keras.layers.GlobalAveragePooling2D()(last)
-        
-        # x = tf.keras.layers.Flatten(name='classify-1')(last)
-        # x = tf.keras.layers.Dense(512, kernel_initializer='he_normal')(x)
-        # x = tf.keras.layers.Activation('relu')(x)
-
         if classes != 2:
-            x = tf.keras.layers.Dense(classes,dtype='float32',kernel_initializer='he_normal')(x)
+            x = tf.keras.layers.Dense(classes,dtype='float32',kernel_initializer='he_normal')(last)
             x = tf.keras.layers.Activation('softmax',dtype='float32')(x)
         else:
-            x = tf.keras.layers.Dense(classes,dtype='float32',kernel_initializer='he_normal')(x)
+            x = tf.keras.layers.Dense(classes,dtype='float32',kernel_initializer='he_normal')(last)
             x = tf.keras.layers.Activation('sigmoid',dtype='float32')(x)
         return tf.keras.Model(input,x)
 
